@@ -2,7 +2,7 @@
 package CPAN::Mirrored::By;
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf "%.6f", substr(q$Rev: 725 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 758 $,4)/1000000 + 5.4;
 
 sub new { 
     my($self,@arg) = @_;
@@ -21,7 +21,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec;
 use vars qw($VERSION);
-$VERSION = sprintf "%.6f", substr(q$Rev: 725 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 758 $,4)/1000000 + 5.4;
 
 =head1 NAME
 
@@ -250,6 +250,17 @@ Shall we use it as the general CPAN build and cache directory?
                   ($default ? 'yes' : 'no'));
     $CPAN::Config->{check_sigs} = ($ans =~ /^y/i ? 1 : 0);
 
+    #
+    # CPAN::Reporter
+    #
+    $CPAN::Frontend->myprint($prompts{test_report_intro});
+
+    defined($default = $CPAN::Config->{test_report}) or
+        $default = 0;
+    $ans = prompt($prompts{test_report},
+                  ($default ? 'yes' : 'no'));
+    $CPAN::Config->{test_report} = ($ans =~ /^y/i ? 1 : 0);
+
     #
     # External programs
     #
@@ -275,7 +286,7 @@ Shall we use it as the general CPAN build and cache directory?
       my $progcall = $progname;
       # we don't need ncftp if we have ncftpget
       next if $progname eq "ncftp" && $CPAN::Config->{ncftpget} gt " ";
-      my $path = $CPAN::Config->{$progname} 
+      my $path = $CPAN::Config->{$progname}
 	  || $Config::Config{$progname}
 	      || "";
       if (File::Spec->file_name_is_absolute($path)) {
@@ -284,6 +295,8 @@ Shall we use it as the general CPAN build and cache directory?
 
 	# warn "Warning: configured $path does not exist\n" unless -e $path;
 	# $path = "";
+      } elsif ($path =~ /^\s+$/) {
+          # preserve disabled programs
       } else {
 	$path = '';
       }
@@ -420,6 +433,7 @@ Shall we use it as the general CPAN build and cache directory?
     $CPAN::Config->{inhibit_startup_message} = 0;
     $CPAN::Config->{getcwd}                  = 'cwd';
     $CPAN::Config->{ftp_passive}             = 1;
+    $CPAN::Config->{term_ornaments}          = 1;
 
     $CPAN::Frontend->myprint("\n\n");
     CPAN::HandleConfig->commit($configpm);
@@ -849,6 +863,29 @@ check_sigs =>
 qq{Always try to check and verify signatures if a SIGNATURE file is in the package
 and Module::Signature is installed (yes/no)?},
 
+test_report_intro =>
+qq{
+
+The goal of the CPAN Testers project (http://testers.cpan.org/) is to
+test as many CPAN packages as possible on as many platforms as
+possible.  This provides valuable feedback to module authors and
+potential users to identify bugs or platform compatibility issues and
+improves the overall quality and value of CPAN.
+
+One way you can contribute is to send test results for each module
+that you install.  If you install the CPAN::Reporter module, you have
+the option to automatically generate and email test reports to CPAN
+Testers whenever you run tests on a CPAN package.
+
+See the CPAN::Reporter documentation for additional details and 
+configuration settings.  If your firewall blocks outgoing email, 
+you will need to configure CPAN::Reporter before sending reports.
+
+},
+
+test_report =>
+qq{Email test reports if CPAN::Reporter is installed (yes/no)?},
+
 external_progs => qq{
 
 The CPAN module will need a few external programs to work properly.
