@@ -2,7 +2,7 @@ package CPAN::HandleConfig;
 use strict;
 use vars qw(%can %keys $VERSION);
 
-$VERSION = sprintf "%.6f", substr(q$Rev: 729 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 758 $,4)/1000000 + 5.4;
 
 %can = (
         commit   => "Commit changes to disk",
@@ -58,6 +58,8 @@ $VERSION = sprintf "%.6f", substr(q$Rev: 729 $,4)/1000000 + 5.4;
                              "show_upload_date",
                              "tar",
                              "term_is_latin",
+                             "term_ornaments",
+                             "test_report",
                              "unzip",
                              "urllist",
                              "username",
@@ -551,7 +553,7 @@ package
 
 use strict;
 use vars qw($AUTOLOAD $VERSION);
-$VERSION = sprintf "%.2f", substr(q$Rev: 729 $,4)/100;
+$VERSION = sprintf "%.2f", substr(q$Rev: 758 $,4)/100;
 
 # formerly CPAN::HandleConfig was known as CPAN::Config
 sub AUTOLOAD {
